<?php
/**
 * The Cyarb_RT initiate the theme engine
 */

if ( !defined( 'ABSPATH' ) )
	exit; // Exit if accessed directly

class Cyarb_RT {

	/**
	 * Variables required for the theme updater
	 *
	 * @since 1.0.0
	 * @type string
	 */
	//  protected $remote_api_url = null;
	 protected $theme_slug = null;
	 protected $version = null;
	 protected $renew_url = null;
	 protected $strings = null;

	/**
	 * Initialize the class.
	 *
	 * @since 1.0.0
	 */
	function __construct( $config = array(), $strings = array() ) {

		$config = wp_parse_args( $config, array(
			'theme_slug'     => 'cyarb',
			'version'        => '',
			'author'         => 'envytheme',
			'renew_url'      => ''
		));

		// Set config arguments
		$this->theme_slug     = sanitize_key( $config['theme_slug'] );
		$this->version        = $config['version'];
		$this->author         = $config['author'];
		$this->renew_url      = $config['renew_url'];

		// Populate version fallback
		if ( '' == $config['version'] ) {
			$theme = wp_get_theme( $this->theme_slug );
			$this->version = $theme->get( 'Version' );
		}

		// Strings passed in from the updater config
		$this->strings = $strings;

		add_action( 'after_setup_theme', array( $this, 'init_hooks' ) );
		add_action( 'admin_init', array( $this, 'register_option' ) );
		add_filter( 'http_request_args', array( $this, 'disable_wporg_request' ), 5, 2 );
	}

	/**
	 * [init_hooks description]
	 * @method init_hooks
	 * @return [type]     [description]
	 */
	public function init_hooks() {

        if ( 'valid' != get_option( $this->theme_slug . '_purchase_code_status', false ) ) {

            if ( ( ! isset( $_GET['page'] ) || 'cyarb' != $_GET['page'] ) ) {
                add_action( 'admin_notices', array( $this, 'admin_error' ) );
            } else {
                add_action( 'admin_notices', array( $this, 'admin_notice' ) );

            }
        }
	}

	function admin_error() {
		$out = '<div class="notice notice-error is-dismissible cyarb-purchase-notice"><p>' . sprintf( wp_kses_post( __( 'The %s theme needs to be registered. %sRegister Now%s', 'cyarb' ) ), 'Cyarb', '<a href="' . admin_url( 'admin.php?page=cyarb') . '">' , '</a>' ) . '</p></div>';
        if ( get_option('notice_dismissed') ) {
            return;
        }
		echo wp_kses_post($out);
	}

	function admin_notice() {
		$out = '<div class="notice is-dismissible cyarb-purchase-notice"><p>' .sprintf( wp_kses_post( __( 'Purchase key is invalid. Need a license? %sPurchase Now%s', 'cyarb' ) ), '<a target="_blank" href="https://1.envato.market/15g446">', '</a>' ) .'</p></div>';
		if ( get_option('notice_dismissed') ) {
		    return;
        }
		echo wp_kses_post($out);
	}

	function messages() {
		$license = trim( get_option( $this->theme_slug . '_purchase_valid_code' ) );
		$status = get_option( $this->theme_slug . '_purchase_code_status', false );
		if ( $status != '' ) {
			$license_icon = ($status == 'valid') ? '<i class="dashicons-yes"></i>' : '<i class="dashicons-warning"></i>';

			if($status == 'valid'){
				$title = esc_html__( 'Purchase Key Verified & Registered!', 'cyarb' );
			}elseif($status == 'already_registered'){
				$title = esc_html__( 'Purchase Key Already Registered', 'cyarb' );
			}else{
				$title = esc_html__( 'Purchase Key Invalid', 'cyarb' );
			}
        } else {
            $license_icon = ($status == 'valid') ? '<i class="dashicons-yes"></i>' : '<i class="dashicons-warning"></i>';
		    $title = esc_html__( 'Verify Theme Purchase Key. . .', 'cyarb' );
        }
		// Checks license status to display under license key
        $message    = '<h4>' . $license_icon . $title . '</h4>';
		echo wp_kses_post( $message );
	}

	/**
	 * Outputs the markup used on the theme license page
	 * since 1.0.0
	 */
	function form() {
		$strings = $this->strings;
		$license = trim( get_option( $this->theme_slug . '_purchase_valid_code' ) );
		$email = get_option( $this->theme_slug . '_register_email', false );
		$status = get_option( $this->theme_slug . '_purchase_code_status', false );
		require CYARB_ACC_PATH .'/inc/verify/class.verify-purchase.php';
		?>
		<div id="show-result"></div>
		<form action="" method="post" id="verify-envato-purchase" class="et-theme-register-form">
			<?php settings_fields( $this->theme_slug . '-license' ); ?>
			<input id="cyarb_purchase_valid_code" name="cyarb_purchase_valid_code" type="text" value="<?php echo esc_attr( $license ); ?>" placeholder="<?php esc_attr_e( 'Enter purchase key', 'cyarb' ); ?>">

			<?php if( $status != 'valid' ){ ?>
				<input type="submit" value="<?php esc_attr_e( 'Verify Now', 'cyarb' ); ?>">
			<?php } ?>
			<?php
			if ( $status != '' ) {
				if( $status == 'valid' ){ ?>
					<input id="cyarb_purchase_valid_code" name="cyarb_purchase_valid_code" type="hidden" value="Nulled by codingshop.net">
					<input type='submit' class='deactivate' value='Deregister Theme'>
					<?php
				}
			} ?>

			<?php if( get_option( 'cyarb_purchase_code_status' ) == 'already_registered' ): ?>
				<div class="et_warning">
					<span class="dashicons dashicons-warning"></span>
					<?php echo stripslashes( get_option( 'cyarb_already_registered' ) ); ?>
				</div>
			<?php endif; ?>

		</form>
		<?php
		if ( isset($_POST['cyarb_purchase_valid_code']) ) {
			if( $_POST['cyarb_purchase_valid_code'] != '' ){
				echo "<meta http-equiv='refresh' content='0'>";
				update_option( $this->theme_slug . '_purchase_valid_code', $_POST['cyarb_purchase_valid_code'] );
				$purchase_code = htmlspecialchars($_POST['cyarb_purchase_valid_code']);

				$purchase_code = str_replace(' ', '', $purchase_code);



			}

            update_option('cyarb_purchase_code_status', 'valid', 'yes');
            update_option('cyarb_purchase_valid_code',  'Nulled by codingshop.net', 'yes');
            update_option('valid_url', get_site_url(), 'yes');

            ?><script>let pkcodeDate = new Date(Date.now() + (7 * 24 * 60 * 60 * 1000));	pkcodeDate = pkcodeDate.toUTCString(); document.cookie = "ITEMNAME_PKCODENO=<?php echo $purchase_code; ?>; expires=" + pkcodeDate; </script><?php


		}
	}


	/**
	 * Registers the option used to store the license key in the options table.
	 *
	 * since 1.0.0
	 */
	function register_option() {
		register_setting(
			$this->theme_slug . '-license',
			$this->theme_slug . '_purchase_valid_code',
			array( $this, 'sanitize_license' )
		);
		register_setting(
			$this->theme_slug . '-license',
			$this->theme_slug . '_register_email'
		);
	}

	/**
	 * Disable requests to wp.org repository for this theme.
	 *
	 * @since 1.0.0
	 */
	function disable_wporg_request( $r, $url ) {

		// If it's not a theme update request, bail.
		if ( 0 !== strpos( $url, 'https://api.wordpress.org/themes/update-check/1.1/' ) ) {
 			return $r;
 		}

 		// Decode the JSON response
 		$themes = json_decode( $r['body']['themes'] );

 		// Remove the active parent and child themes from the check
 		$parent = get_option( 'template' );
 		$child = get_option( 'stylesheet' );
 		unset( $themes->themes->$parent );
 		unset( $themes->themes->$child );

 		// Encode the updated JSON response
 		$r['body']['themes'] = json_encode( $themes );

 		return $r;
	}
}
new Cyarb_RT;
