<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = CYARB_FRAMEWORK_VAR;
    
    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'opt_name/opt_name', $opt_name );

    // Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    
    if ( is_dir( $sample_patterns_path ) ) {
        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();
            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {
                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    // All the possible arguments for Redux.
    $theme = wp_get_theme(); // For use with some settings. Not necessary.
    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Theme Options', 'cyarb-toolkit' ),
        'page_title'           => __( 'Theme Options', 'cyarb-toolkit' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 90,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'cyarb_option',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '<p></p>', 'cyarb-toolkit' ), $v );
    } else {
        $args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'cyarb-toolkit' );
    }
    Redux::setArgs( $opt_name, $args );
    // END ARGUMENTS

// General Options
Redux::setSection( $opt_name, array(
    'title'             => __( 'General Options', 'cyarb-toolkit' ),
    'id'                => 'general_options',
    'customizer'        => false,
    'icon'              => ' el el-home',
    'fields'     => array(
        array(
            'id'       => 'cyarb_logo',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Site Logo', 'cyarb-toolkit' ),
            'desc'     => __( 'Recommended sizes - width: 142px, height: 48px.', 'cyarb-toolkit' ),
        ),
        array(
            'title'     => __( 'Site Logo dimensions', 'cyarb-toolkit' ),
            'subtitle'  => __( 'Set a custom height width for your upload logo. Recommended size 142X48', 'cyarb-toolkit' ),
            'id'        => 'site_logo_dimensions',
            'type'      => 'dimensions',
            'units'     => array( 'em','px','%' ),
            'output'    => '.navbar-brand img'
        ),
        array(
            'id'       => 'mobile_logo',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Site Mobile Logo (optional)', 'cyarb-toolkit' ),
            'desc'     => __( 'Recommended sizes - width: 142px, height: 48px.', 'cyarb-toolkit' ),
        ),
        array(
            'title'     => __( 'Mobile Logo dimensions', 'cyarb-toolkit' ),
            'subtitle'  => __( 'Set a custom height width for your upload logo. Recommended size 142X48', 'cyarb-toolkit' ),
            'id'        => 'mobile_logo_dimensions',
            'type'      => 'dimensions',
            'units'     => array( 'em','px','%' ),
            'output'    => '.cyard-responsive-nav .logo img'
        ),
        array(
            'id'        => 'disable_sticky_header',
            'type'      => 'switch',
            'title'     => __('Disable Sticky Header', 'cyarb-toolkit'),
            'desc'      => __('', 'cyarb-toolkit'),
            'default'   => '0',
        ),
        array(
            'id'        => 'enable_back_to_top',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Back To Top Button', 'cyarb-toolkit'),
            'default'   => '1'
        ),
        array(
            'id'      => 'cyarb_enable_rtl',
            'type'    => 'select',
            'options' => array(
                'enable'        => 'Enable',
                'disable'       => 'Disable',
            ),
            'title'     => esc_html__( 'RTL', 'cyarb-toolkit' ),
            'default'   => 'disable',
        ),
        array(
            'id'        => 'cyarb_cta_enable',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Footer CTA?', 'cyarb-toolkit'),
            'default'   => '1'
        ),
        array(
            'id'        => 'cyarb_pl_enable',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Footer Partner Logo?', 'cyarb-toolkit'),
            'default'   => '1'
        ),

        array(
            'id'      => 'enable_cart_btn',
            'type'    => 'switch',
            'title'   => __('Enable Woocommerce Cart', 'cyarb-toolkit'),
            'default' => '1'
        ),
    ),
) );

// Top Header 
Redux::setSection( $opt_name, array(
    'title'             => __( 'Top Header', 'cyarb-toolkit' ),
    'id'                => 'top_header',
    'customizer'        => false,
    'icon'              => 'el el-website',
    'fields'            => array(
        array(
            'id'       => 'cyarb_hide_top_header',
            'type'     => 'checkbox',
            'title'    => __( 'Top Header Hide?', 'cyarb-toolkit' ),
            'default'  => '0',
        ),
        array(
            'id'            => 'company_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Company Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header company text', 'cyarb-toolkit'),
            'default'       => esc_html__( 'Join our company', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'company_url',
            'type'          => 'text',
            'title'         => esc_html__('Header Company URL', 'cyarb-toolkit'),
            'desc'          => esc_html__('header company url', 'cyarb-toolkit'),
            'default'       => esc_html__('#', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'email_level_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Email Label Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header email label text', 'cyarb-toolkit'),
            'default'       => esc_html__( 'Email:', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'email_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Email Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header email text', 'cyarb-toolkit'),
            'default'       => esc_html__( 'hello@cyarb.com', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'email_icon',
            'type'          => 'text',
            'title'         => esc_html__('Header Email Icon', 'cyarb-toolkit'),
            'desc'          => esc_html__('header email icon', 'cyarb-toolkit'),
            'default'       => esc_html__( 'lni lni-envelope', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'email_url',
            'type'          => 'text',
            'title'         => esc_html__('Header Email URL', 'cyarb-toolkit'),
            'desc'          => esc_html__('header email url', 'cyarb-toolkit'),
            'default'       => esc_html__('mailto:hello@cyarb.com', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'contact_level_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Contact Label Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header contact label text', 'cyarb-toolkit'),
            'default'       => esc_html__( 'Phone:', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'contact_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Contact Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header contact text', 'cyarb-toolkit'),
            'default'       => esc_html__( '+1 (514) 312-5678', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'contact_icon',
            'type'          => 'text',
            'title'         => esc_html__('Header Contact Icon', 'cyarb-toolkit'),
            'desc'          => esc_html__('header contact icon', 'cyarb-toolkit'),
            'default'       => esc_html__( 'lni lni-phone', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'contact_url',
            'type'          => 'text',
            'title'         => esc_html__('Header Contact URL', 'cyarb-toolkit'),
            'desc'          => esc_html__('header contact url', 'cyarb-toolkit'),
            'default'       => esc_html__( 'tel:+1-(514)-312-5678', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),

        array(
            'id'            => 'support_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Support Center Text', 'cyarb-toolkit'),
            'desc'          => esc_html__('header support center text', 'cyarb-toolkit'),
            'default'       => esc_html__( 'Support Center', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'support_icon',
            'type'          => 'text',
            'title'         => esc_html__('Header Support Icon', 'cyarb-toolkit'),
            'desc'          => esc_html__('header support icon', 'cyarb-toolkit'),
            'default'       => esc_html__( 'lni lni-headphone-alt', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),
        array(
            'id'            => 'support_url',
            'type'          => 'text',
            'title'         => esc_html__('Header Support URL', 'cyarb-toolkit'),
            'desc'          => esc_html__('header support url', 'cyarb-toolkit'),
            'default'       => esc_html__('#', 'cyarb-toolkit' ),
            'required'      => array('cyarb_hide_top_header','=','0'),
        ),

        array(
            'id'        => 'is_top_social',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Social Icon', 'cyarb-toolkit'),
            'default'   => '1'
        ),
    ),
) );

// Header 
Redux::setSection( $opt_name, array(
    'title'             => __( 'Header', 'cyarb-toolkit' ),
    'id'                => 'header',
    'customizer'        => false,
    'icon'              => 'el el-website',
    'fields'            => array(
        array(
            'id' => 'cyarb_enable_search',
            'type' => 'switch',
            'title' => esc_html__('Enable Search Option', 'cyarb-toolkit'),
            'default' => '1'
        ),
        array(
			'id'         => 'cyarb_search_placeholder_text',
            'type'       => 'text',
			'title'      => esc_html__('Search Placeholder Text', 'cyarb-toolkit'),
            'required'   => array('cyarb_enable_search','equals','1'),
        ), 
        array(
            'id'            => 'enable_button',
            'type'          => 'switch',
            'title'         => esc_html__('Enable Header Button', 'cyarb-toolkit'),
            'default'       => '1'
        ),
        array(
            'id'            => 'button_text',
            'type'          => 'text',
            'title'         => esc_html__('Header Button Name', 'cyarb-toolkit'),
            'desc'          => esc_html__('type header button name', 'cyarb-toolkit'),
            'default'       => esc_html__('Get A Quote', 'cyarb-toolkit'),
            'required'      => array('enable_button','equals','1'),
        ),

        array(
            'id'            => 'btn_link_type',
            'type'          => 'select',
            'options' => array (
                'external_link'     => 'External Link',
                'link_to_page'     => 'Link To Page',
            ),
            'title'     => esc_html__( 'Link Type', 'cyarb-toolkit' ),
            'default'   => 'link_to_page',
            'required'      => array('enable_button','equals','1'),
        ),
        array(
			'id'        => 'external_link',
            'type'      => 'text',
			'title'     => esc_html__('External Link', 'cyarb-toolkit'),
            'required'  => array('btn_link_type','equals','external_link'),
        ),
        array(
			'id'        => 'link_to_page',
            'type'  => 'select',
            'options'   => cyarb_toolkit_get_page_as_list(),
			'title'     => esc_html__('Link Page', 'cyarb-toolkit'),
            'required'  => array('btn_link_type','equals','link_to_page'),
            'condition'   => [
                'btn_link_type' => '2',
            ],
        ),
        array(
			'id'        => 'target_page',
            'type'  => 'select',
            'title'     => esc_html__('Link Open In New Tab?', 'cyarb-toolkit'),
            'options' => array (
                'no'     => 'No',
                'yes'    => 'Yes',
            ),
            'default' => 'yes',
            'required'      => array('enable_button','equals','1'),
        ),
    ),
) );

/* Social Profiles */
Redux::setSection( $opt_name, array(
	'title' => __('Social Profiles', 'cyarb-toolkit'),
	'desc' => 'Social profiles are used in different places inside the theme.',
	'icon' => 'el-icon-user',
	'customizer' => false,
	'fields' => array(
        array(
            'id' => 'cyarb_social_target',
            'type' => 'select',
            'options' => array(
                '_blank'    => 'Load in a new window. ( _blank )',
                '_self'     => 'Load in the same frame as it was clicked. ( _self )',
            ),
            'title'     => __( 'Social Link Target', 'cyarb-toolkit' ),
            'default'   => '_blank',
        ),
        array(
			'id' => 'facebook-url',
			'type' => 'text',
			'title' =>__('Facebook URL', 'cyarb-toolkit'),
            'default' =>__('#'),
		),
        array(
			'id' => 'twitter-url',
            'type' => 'text',
			'title' => __('Twitter URL', 'cyarb-toolkit'),
            'default' =>__('#'),
        ),
        array(
			'id' => 'linkedin-url',
			'type' => 'text',
			'title' => __('Linkedin URL', 'cyarb-toolkit'),
            'default' =>__('#'),
        ),
        array(
			'id' => 'instagram-url',
            'type' => 'text',
			'title' => __('Instagram URL', 'cyarb-toolkit'),
            'default' =>__('#'),
        ),
        array(
			'id' => 'youtube-url',
			'type' => 'text',
			'title' =>  __('Youtube URL', 'cyarb-toolkit')
		),
        array(
			'id' => 'paypal-url',
			'type' => 'text',
			'title' =>__('Paypal URL', 'cyarb-toolkit')
		),
        array(
			'id' => 'google-url',
			'type' => 'text',
			'title' =>  __('Google URL', 'cyarb-toolkit')
		),
		array(
			'id' => 'pinterest-url',
			'type' => 'text',
			'title' =>__('Pinterest URL', 'cyarb-toolkit')
		),
		array(
			'id' => 'dribbble-url',
			'type' => 'text',
			'title' =>__('Dribbble URL', 'cyarb-toolkit')
		),
		array(
			'id' => 'tumblr-url',
			'type' => 'text',
			'title' =>__('Tumblr URL', 'cyarb-toolkit')
		),
		array(
			'id' => 'call-url',
			'type' => 'text',
			'title' =>__('Call URL', 'cyarb-toolkit')
		),
		array(
			'id' => 'email-url',
			'type' => 'text',
			'title' =>__('Email URL', 'cyarb-toolkit')
		),
	)
) );

// Page Banner Shapes
Redux::setSection( $opt_name, array(
    'title'             => __( 'Page Banner', 'rola-toolkit' ),
    'id'                => 'shape_images_options',
    'customizer'        => false,
    'icon'              => 'el el-website',
    'fields'     => array(

        array(
            'id'        => 'cyarb_banner_image_shape',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Page Banner Shape', 'cyarb-toolkit'),
            'default'   => '1'
        ),

        array(
            'id'       => 'page_banner_title_color',
            'type'     => 'color',
            'title'    => __('Page Banner Background Color', 'rola-toolkit'),
            'validate' => 'color',
            'output'      => array(
                'background-color' => '.page-title-area',
            ),
            'transparent' => true,
        ),
        array(
            'id'        => 'pagebanner_breadcrumb',
            'type'      => 'typography',
            'title'     => __( 'Title Typography', 'rola-toolkit' ),
            'output'    => '.page-title-area h1'
        ),

        array(
            'id'        => 'pagebanner_breadcrumb_typo',
            'type'      => 'typography',
            'title'     => __( 'Breadcrumb Typography', 'rola-toolkit' ),
            'output'    => '.page-title-content ul li a, .page-title-content ul li',
        ),

        array(
            'title'     => esc_html__( 'Banner Padding', 'rola-toolkit' ),
            'subtitle'  => esc_html__( 'Padding around the Banner.', 'rola-toolkit' ),
            'id'        => 'banner_padding',
            'type'      => 'spacing',
            'output'    => array( '.page-title-area' ),
            'mode'      => 'padding',
            'units'     => array( 'em', 'px', '%' ),
            'units_extended' => 'true',
        ),
        array(
            'id'       => 'page_banner_bg_color',
            'type'     => 'color',
            'title'    => __('Page Banner Background Color', 'rola-toolkit'),
            'validate' => 'color',
            'output'      => array(
                'background-color' => '.page-title-area',
            ),
            'transparent' => true,
        ),
    )
) );

// CTA Area
Redux::setSection( $opt_name, array(
    'title'             => __( 'CTA Area', 'cyarb-toolkit' ),
    'id'                => 'cta',
    'customizer'        => false,
    'icon'              => 'el el-edit',
    'fields' => array(
        
        array(
            'id'        => 'cyarb_cta_image_shape',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Footer CTA Shape', 'cyarb-toolkit'),
            'default'   => '1'
        ),

        array(
            'id'            => 'cyarb_cta_text',
            'type'          => 'text',
            'title'         => esc_html__('Footer CTA Text', 'cyarb-toolkit'),
            'default'       => esc_html__('Let’s talk about how can help you securely advance.', 'cyarb-toolkit' ),
        ),   
        array(
            'id'            => 'cta_button_text',
            'type'          => 'text',
            'title'         => esc_html__('Footer CTA Button Name', 'cyarb-toolkit'),
            'desc'          => esc_html__('type footer button name', 'cyarb-toolkit'),
            'default'       => esc_html__('Get A Free Quote', 'cyarb-toolkit'),
        ),

        array(
            'id'            => 'cta_btn_link_type',
            'type'          => 'select',
            'options' => array (
                'cta_external_link'     => 'External Link',
                'cta_link_to_page'     => 'Link To Page',
            ),
            'title'     => esc_html__( 'Link Type', 'cyarb-toolkit' ),
            'default'   => 'cta_link_to_page',
        ),
        array(
			'id'        => 'cta_external_link',
            'type'      => 'text',
			'title'     => esc_html__('External Link', 'cyarb-toolkit'),
            'required'  => array('cta_btn_link_type','equals','cta_external_link'),
        ),
        array(
			'id'        => 'cta_link_to_page',
            'type'  => 'select',
            'options'   => cyarb_toolkit_get_page_as_list(),
			'title'     => esc_html__('Link Page', 'cyarb-toolkit'),
            'required'  => array('cta_btn_link_type','equals','cta_link_to_page'),
            'condition'   => [
                'cta_btn_link_type' => '2',
            ],
        ),
        array(
			'id'        => 'cta_target_page',
            'type'  => 'select',
            'title'     => esc_html__('Link Open In New Tab?', 'cyarb-toolkit'),
            'options' => array (
                'no'     => 'No',
                'yes'    => 'Yes',
            ),
            'default' => 'yes',
        ),
    ) 
));

// Footer Area
Redux::setSection( $opt_name, array(
    'title'             => __( 'Footer', 'cyarb-toolkit' ),
    'id'                => 'footer',
    'customizer'        => false,
    'icon'              => 'el el-edit',
    'fields' => array(
        array(
            'id'        => 'cyarb_footer_copyright_text',
            'type'      => 'editor',
            'title'     => esc_html__('Footer Copyright Text (optional)', 'cyarb-toolkit'),
            'default'   => 'Copyright ©2021 Design &amp; Developed By <a href="https://envytheme.com/" target="_blank">Envytheme</a>',
        ),
        array(
            'id'       => 'cyarb_footer_bg',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Footer Background Image', 'cyarb-toolkit' ),
            'desc'     => esc_html__('For footer style 1 & 2', 'cyarb-toolkit'),
        ),
        array(
            'id'        => 'cyarb_footer_image_shape',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Page Footer Shape', 'cyarb-toolkit'),
            'default'   => '1'
        ),
        array(
            'id'        => 'cyarb_footer_shape1',
            'type'      => 'media',
            'url'       => true,
            'title'     => __( 'Footer Shape', 'cyarb-toolkit' ),
            'required'  => array('cyarb_footer_image_shape','equals','1'),
        ),
        array(
            'id'        => 'cyarb_footer_shape2',
            'type'      => 'media',
            'url'       => true,
            'title'     => __( 'Footer Shape 2', 'cyarb-toolkit' ),
            'required'  => array('cyarb_footer_image_shape','equals','1'),
            'desc'     => esc_html__('For footer style 3', 'cyarb-toolkit'),
        ),
        array(
            'id'    => 'footer_col',
            'type'  => 'select',
            'options' => array(
                'column-2'  => 'Grid 2',
                'column-3'  => 'Grid 3',
                'column-4'  => 'Grid 4',
            ),
            'title'     => __( 'Choose Footer Column', 'cyarb-toolkit' ),
            'default'   => 'column-4',
        ),

        array(
            'id'            => 'footer_bg',
            'type'          => 'color',
            'title'         => esc_html__('Footer Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.footer-area',
            ),
            'desc'        => esc_html__('Background color will show when there is no background image', 'cyarb-toolkit'),
        ),
        array(
            'id'            => 'footer_title_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Title Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.single-footer-widget h3, .single-footer-widget h2, .single-footer-widget .logo h2',
            ),
        ),
        array(
            'id'            => 'footer_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Text Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.single-footer-widget .footer-contact-info li span, .single-footer-widget.widget_cyarb_logo_info p, .single-footer-widget ul li, .single-footer-widget ul li a, .single-footer-widget .footer-contact-info li a, .single-footer-widget .footer-contact-info li, .copyright-area p',
            ),
        ),
        array(
            'id'            => 'footer_link_text',
            'type'          => 'color',
            'title'         => esc_html__('Copyright Link Text Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.copyright-area p a',
            ),
        ),
        array(
            'id'            => 'footer_link_texth',
            'type'          => 'color',
            'title'         => esc_html__('Copyright Link Text Hover Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.copyright-area p a:hover',
            ),
        ),
        array(
            'id'            => 'footer_social_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Social Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => ' .single-footer-widget .social-links li a',
            ),
        ),
        array(
            'id'            => 'footer_social_bgtext',
            'type'          => 'color',
            'title'         => esc_html__('Footer Social Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => ' .single-footer-widget .social-links li a',
            ),
        ),
        array(
            'id'            => 'footer3_news_bg',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => '.single-footer-widget .newsletter-box',
            ),
        ),
        array(
            'id'            => 'footer3_news_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Text Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.footer-style-two-with-color .single-footer-widget .newsletter-box p, .single-footer-widget .newsletter-box p',
            ),
        ),
        array(
            'id'            => 'footer3_place_bg',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Placeholder Background', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => '.footer-style-two-with-color .single-footer-widget .newsletter-form .input-newsletter,  .single-footer-widget .newsletter-form .input-newsletter',
            ),
        ),
        array(
            'id'            => 'footer3_place_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Placeholder Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.footer-style-two-with-color .single-footer-widget .newsletter-form .input-newsletter, .footer-style-two-with-color .single-footer-widget .newsletter-form .input-newsletter::placeholder,  .single-footer-widget .newsletter-form .input-newsletter, .single-footer-widget .newsletter-form .input-newsletter::placeholder',
            ),
        ),
        array(
            'id'            => 'footer3_form_btn_bg',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Button Background', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => '.single-footer-widget .newsletter-box button',
            ),
        ),
        array(
            'id'            => 'footer3_form_btn_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Newsletter Button Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.single-footer-widget .newsletter-box button',
            ),
        ),
    ) 
));

Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Styling Option Footer(style 3)', 'rola-toolkit' ),
	'id'        => 'footer_stl3_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(

        array(
            'id' => 'footer3_bg',
            'type' => 'color',
            'title' => __('Footer Background Color', 'rola-toolkit'),
            'validate' => 'color',
            'output'      => array(
                'background-color' => '.footer-style-two-with-color',
            ),
            'transparent' => false
        ),
        array(
            'id'            => 'footer3_head_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Heading Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.footer-style-two-with-color .single-footer-widget h3, .footer-style-two-with-color .single-footer-widget h2, .footer-style-two-with-color .single-footer-widget .logo h2',
            ),
        ),
        array(
            'id'            => 'footer3_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Text Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.footer-style-two-with-color .single-footer-widget p, .single-footer-widget ul li, .footer-style-two-with-color .single-footer-widget .footer-contact-info li span, .footer-style-two-with-color .single-footer-widget .footer-contact-info li a, .footer-style-two-with-color .single-footer-widget .footer-contact-info li, .footer-style-two-with-color .single-footer-widget ul li a',
            ),
        ),

        
        array(
            'id'            => 'footer3_social_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Social Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.footer-style-two-with-color .single-footer-widget .social-links li a',
            ),
        ),
        array(
            'id'            => 'footer3_social_bgtext',
            'type'          => 'color',
            'title'         => esc_html__('Footer Social Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => '.footer-style-two-with-color .single-footer-widget .social-links li a',
            ),
        ),
        
        array(
            'id'            => 'footer3_copy_bg',
            'type'          => 'color',
            'title'         => esc_html__('Footer Copyright Background', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'background-color' => '.copyright-style-two-with-color',
            ),
        ),
        array(
            'id'            => 'footer3_copy_text',
            'type'          => 'color',
            'title'         => esc_html__('Footer Copyright Text Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.copyright-style-two-with-color p',
            ),
        ),
        array(
            'id'            => 'footer3_copy_linktext',
            'type'          => 'color',
            'title'         => esc_html__('Footer Copyright Text Link Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.copyright-style-two-with-color p a',
            ),
        ),
        array(
            'id'            => 'footer3_copy_linkhtext',
            'type'          => 'color',
            'title'         => esc_html__('Footer Copyright Text Link Hover Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'        => array(
                'color' => '.copyright-style-two-with-color p a:hover',
            ),
        ),
	)
));

// Styling 
Redux::setSection( $opt_name, array(
    'title'        => __( 'Styling Options', 'cyarb-toolkit' ),
    'id'           => 'styling_options',
    'customizer'   => false,
    'icon'         => ' el el-magic',
    'fields'     => array(
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => __('Primary Color', 'cyarb-toolkit'),
            'default'     => '#ed1d61',
            'validate'    => 'color',
            'output'      => array(
                '--mainColor' => ':root',
            ),
            'transparent' => false
        ),
    ),
) );
// Top Header
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Top Header', 'rola-toolkit' ),
	'id'        => 'ths_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'          => 'top_header_color',
            'type'        => 'color',
            'title'       => __('Top Header Text Color', 'cyarb-toolkit'),
            'validate'    => 'color',
            'output'      => array(
                'color' => '.top-header-contact-info li a, .top-header-contact-info li, .top-header-contact-info li.email a, .top-header-contact-info li.phone-number a, .top-header-right-side li a, .header-area.white-header .top-header-contact-info li, .header-area.white-header .top-header-contact-info li a, .header-area.white-header .top-header-contact-info li.email a, .header-area.white-header .top-header-contact-info li.phone-number a, .header-area.white-header .top-header-right-side li a, .cyard-new-top-header-area .top-header-contact-info li a, .cyard-new-top-header-area .top-header-contact-info li, .cyard-new-top-header-area .top-header-right-side li a',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'top_header_linkcolor',
            'type'        => 'color',
            'title'       => __('Top Header Link Text Color', 'cyarb-toolkit'),
            'validate'    => 'color',
            'output'      => array(
                'color' => '.top-header-contact-info li a:hover,  .top-header-contact-info li.email a:hover, .top-header-contact-info li.phone-number a:hover, .top-header-right-side li a:hover, .header-area.white-header .top-header-right-side li a:hover, .header-area.white-header .top-header-contact-info li.phone-number a:hover, .header-area.white-header .top-header-contact-info li.email a:hover, .header-area.white-header .top-header-contact-info li a:hover, .cyard-new-top-header-area .top-header-contact-info li.phone-number a:hover, .cyard-new-top-header-area .top-header-contact-info li a:hover, .cyard-new-top-header-area .top-header-contact-info li.email a:hover, .cyard-new-top-header-area .top-header-right-side li a i:hover',
            ),
            'transparent' => false
        ),
	)
));
// Navbar style one
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Style One', 'rola-toolkit' ),
	'id'        => 'head_stl1_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'header_bg',
            'type'          => 'color',
            'title'         => esc_html__('Header Background Color.', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false
        ),
        array(
            'id'            => 'nav_item_color',
            'type'          => 'color',
            'title'         => esc_html__('Nav Item Color', 'cyarb-toolkit'),
            'default'       => '#000000',
            'validate'      => 'color',
            'transparent'   => false,
        ),
        array(
            'id'            => 'nav_item_hover_color',
            'type'          => 'color',
            'title'         => esc_html__('Nav Item Hover Color', 'cyarb-toolkit'),
            'default'       => '#ed1d61',
            'validate'      => 'color',
            'transparent'   => false,
        ),
        array(
            'id'            => 'sticky_nav_background',
            'type'          => 'color',
            'title'         => esc_html__('Sticky Nav Background Color', 'cyarb-toolkit'),
            'default'       => '#ffffff',
            'validate'      => 'color',
            'transparent'   => false,
        ),
        
	)
));
// Navbar style two
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Style Two ', 'rola-toolkit' ),
	'id'        => 'head_styl2_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'nav_three_bgcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.header-area.white-header .navbar-area',
            ),
        ),
        array(
            'id'            => 'nav_three_itemcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Item Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.header-area.white-header .cyard-nav .navbar .navbar-nav .nav-item a, .header-area.white-header .cyard-nav .navbar .others-option .option-item .search-cart li .search-icon, .header-area.white-header .cyard-nav .navbar .others-option .option-item .social-links li a',
            ),
        ),
        array(
            'id'            => 'sticky3_nav_background',
            'type'          => 'color',
            'title'         => esc_html__('Nav Sticky Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
	)
));
// Navbar style 3
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Style Three', 'rola-toolkit' ),
	'id'        => 'head_styl3_4_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'nav_thr_bgcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.navbar-area.cyard-new-navbar-area',
            ),
        ),
        array(
            'id'            => 'nav_thr_itemcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Item Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.navbar-area.cyard-new-navbar-area .cyard-nav .navbar .navbar-nav .nav-item a, .navbar-area.cyard-new-navbar-area .cyard-nav .navbar .others-option .option-item .search-cart li .search-icon, .navbar-area.cyard-new-navbar-area .cyard-nav a.navbar-brand h2',
            ),
        ),
        array(
            'id'            => 'stickytr_nav_background',
            'type'          => 'color',
            'title'         => esc_html__('Nav Sticky Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
	)
));
// Navbar style 4
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Style Four', 'rola-toolkit' ),
	'id'        => 'head_styl_4_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'nav_four_bgcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.background-transparent-header .cyard-new-navbar-area',
            ),
        ),
        array(
            'id'            => 'nav_four_itemcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Item Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.background-transparent-header .navbar-area.cyard-new-navbar-area .cyard-nav .navbar .navbar-nav .nav-item a, .background-transparent-header .navbar-area.cyard-new-navbar-area .cyard-nav .navbar .others-option .option-item .search-cart li .search-icon, .background-transparent-header .navbar-area.cyard-new-navbar-area .cyard-nav a.navbar-brand h2',
            ),
        ),
        array(
            'id'            => 'stickyfour_nav_background',
            'type'          => 'color',
            'title'         => esc_html__('Nav Sticky Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
	)
));
// Navbar Button
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Button', 'rola-toolkit' ),
	'id'        => 'head_button_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'nav_item_buttoncolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.cyard-nav .navbar .others-option .option-item .default-btn',
                'border-color' => '.cyard-nav .navbar .others-option .option-item .default-btn',
            ),
        ),
        array(
            'id'            => 'nav_item_buttonbgcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.cyard-nav .navbar .others-option .option-item .default-btn, .header-area.white-header .cyard-nav .navbar .others-option .option-item .default-btn',
                'border-color' => '.cyard-nav .navbar .others-option .option-item .default-btn, .header-area.white-header .cyard-nav .navbar .others-option .option-item .default-btn',
            ),
        ),
        array(
            'id'            => 'nav_item_buttonhbgcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Hover Background Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'background-color' => '.cyard-nav .navbar .others-option .option-item .default-btn:hover, .default-btn::before, .default-btn::after, .default-btn span::before, .default-btn span::after',
            ),
        ),
        array(
            'id'            => 'nav_item_buttonhcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Hover Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.cyard-nav .navbar .others-option .option-item .default-btn:hover, .header-area.white-header .cyard-nav .navbar .others-option .option-item .default-btn:hover',
            ),
        ),
        
	)
));
// Navbar Button style 3/4
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Navbar Button Style(3/4)', 'rola-toolkit' ),
	'id'        => 'head_button34_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'            => 'nav_buttoncolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.default-btn-two',
            ),
        ),
        array(
            'id'            => 'nav_buttonhcolor',
            'type'          => 'color',
            'title'         => esc_html__('Nav Button Hover Color', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
            'output'      => array(
                'color' => '.default-btn-two:hover',
            ),
        ),
        array(
            'id'            => 'nav_button_gc1',
            'type'          => 'color',
            'title'         => esc_html__('Button Gradient Color1', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
        array(
            'id'            => 'nav_button_gc2',
            'type'          => 'color',
            'title'         => esc_html__('Button Gradient Color2', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
        array(
            'id'            => 'nav_button_gc3',
            'type'          => 'color',
            'title'         => esc_html__('Button Gradient Color3', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),

        array(
            'id'            => 'nav_button_hgc1',
            'type'          => 'color',
            'title'         => esc_html__('Button Hover Gradient Color1', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
        array(
            'id'            => 'nav_button_hgc2',
            'type'          => 'color',
            'title'         => esc_html__('Button Hover Gradient Color2', 'cyarb-toolkit'),
            'validate'      => 'color',
            'transparent'   => false,
        ),
	)
));

// Gradient Styling 
Redux::setSection( $opt_name, array(
    'title'        => __( 'Theme Gradient Colors', 'cyarb-toolkit' ),
    'id'           => 'styling_options_grad',
    'customizer'   => false,
    'icon'         => ' el el-magic',
    'fields'     => array(
        array(
            'id'          => 'grad1_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 1', 'cyarb-toolkit'),
            'default'     => '#ed1e79',
            'validate'    => 'color',
            'output'      => array(
                '--gradOne' => ':root',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'grad2_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 2', 'cyarb-toolkit'),
            'default'     => '#f10d66',
            'validate'    => 'color',
            'output'      => array(
                '--gradTwo' => ':root',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'grad3_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 3', 'cyarb-toolkit'),
            'default'     => '#f30251',
            'validate'    => 'color',
            'output'      => array(
                '--gradThree' => ':root',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'grad4_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 4', 'cyarb-toolkit'),
            'default'     => '#f10a3c',
            'validate'    => 'color',
            'output'      => array(
                '--gradFour' => ':root',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'grad5_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 5', 'cyarb-toolkit'),
            'default'     => '#ed1c24',
            'validate'    => 'color',
            'output'      => array(
                '--gradFive' => ':root',
            ),
            'transparent' => false
        ),

    ),
) );
// Gradient Color Two
Redux::setSection( $opt_name, array(
	'title'     => esc_html__( 'Primary Gradient Color Two', 'rola-toolkit' ),
	'id'        => 'pri_grad_color2_settings',
	'icon'      => '',
    'subsection' => true,
	'fields'    => array(
        array(
            'id'          => 'pgrad1_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 1', 'cyarb-toolkit'),
            'default'     => '#ED1D78',
            'validate'    => 'color',
            'output'      => array(
                '--pgradOne' => ':root',
            ),
            'transparent' => false
        ),
        array(
            'id'          => 'pgrad2_color',
            'type'        => 'color',
            'title'       => __('Gradient Color 2', 'cyarb-toolkit'),
            'default'     => '#ED1B25',
            'validate'    => 'color',
            'output'      => array(
                '--pgradTwo' => ':root',
            ),
            'transparent' => false
        ),
	)
));

// Blog Area
Redux::setSection( $opt_name, array(
    'title'         => esc_html__( 'Blog Settings', 'cyarb-toolkit' ),
    'id'            => 'cyarb_blog',
    'customizer'    => false,
    'icon'          => 'el el-file-edit',
    'desc'          => 'Manage your blog settings.',
    'fields' => array(
        array(
			'id'    => 'cyarb_search_page',
            'type'  => 'switch',
            'title' => __('Enable Pages On Search Result Page', 'cyarb-toolkit'),
        ),
        array(
			'id'    => 'hide_blog_banner',
            'type'  => 'switch',
            'title' => __('Hide Blog Banner', 'cyarb-toolkit'),
            'default'   => '0'
        ),

        array(
			'id'    => 'hide_breadcrumb',
            'type'  => 'switch',
			'title' => __('Hide Blog Breadcrumb', 'cyarb-toolkit'),
            'default'   => '0',
            'required'      => array('hide_blog_banner','equals','0'),
        ),
        
        array(
            'id'       => 'blog_title',
            'type'     => 'text',
            'title'    => __( 'Posts Page Banner Title', 'cyarb-toolkit' ),
            'required' => array('hide_blog_banner','equals','0'),
        ),
        array(
			'id'    => 'hide_single_blog_banner',
            'type'  => 'switch',
            'title' => __('Hide Single Blog Banner', 'cyarb-toolkit'),
            'default'   => '0'
        ),

        array(
			'id'    => 'single_hide_breadcrumb',
            'type'  => 'switch',
			'title' => __('Hide Single Blog Breadcrumb', 'cyarb-toolkit'),
            'default'   => '0',
            'required'      => array('hide_single_blog_banner','equals','0'),
        ),

        array(
            'id'       => 'single_count_tag',
            'type'     => 'text',
            'title'    => __( 'Single Posts Tags Number', 'cyarb-toolkit' ),
            'default'  => 1,
        ),

        array(
            'id' => 'cyarb_blog_sidebar',
            'type' => 'select',
            'options' => array(
                'cyarb_with_sidebar'              => 'With Sidebar',
                'cyarb_without_sidebar'           => 'Without Sidebar ( full width )',
                'cyarb_without_sidebar_center'    => 'Without Sidebar( center )',
            ),
            'title'     => __( 'Blog Sidebar', 'cyarb-toolkit' ),
            'default'   => 'cyarb_with_sidebar',
        ),
        array(
            'id'       => 'blog_bg',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Posts Page Banner Background Image', 'cyarb-toolkit' ),
            'required' => array('hide_blog_banner','equals','0'),
        ),
        array(
            'id'       => 'archive_bg',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Archive Page Banner Background Image', 'cyarb-toolkit' ),
        ),
        array(
            'id'       => 'search_bg',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( 'Search Page Banner Background Image', 'cyarb-toolkit' ),
        ),
        
        array(
            'id'    => 'tag_text',
            'type'  => 'text',
            'title' => esc_html__('Tag Text', 'cyarb-toolkit'),
            'default'   => 'Tags:',
        ),

        array(
            'id'       => 'count_tag',
            'type'     => 'text',
            'title'    => __( 'Posts Tags Number', 'cyarb-toolkit' ),
            'default'  => 1,
        ),

        array(
			'title'     => __( 'Post Meta', 'cyarb-toolkit' ),
			'subtitle'  => __( 'Show/hide post meta', 'cyarb-toolkit' ),
			'id'        => 'is_post_meta',
			'type'      => 'switch',
            'on'        => __( 'Show', 'cyarb-toolkit' ),
            'off'       => __( 'Hide', 'cyarb-toolkit' ),
            'default'   => '1',
        ),

        array(
			'title'     => __( 'Post Social Share', 'cyarb-toolkit' ),
			'subtitle'  => __( 'Show/hide post social share', 'cyarb-toolkit' ),
			'id'        => 'enable_blog_post_share',
			'type'      => 'switch',
            'on'        => __( 'Enable', 'cyarb-toolkit' ),
            'off'       => __( 'Disable', 'cyarb-toolkit' ),
            'default'   => '1',
        ),
        array(
            'id'       => 'share_text',
            'type'     => 'text',
            'title'    => esc_html__( 'Social Share Text', 'cyarb-toolkit' ),
            'default'   => 'Share:',
        ),
        array(
			'id'    => 'enable_blog_post_fb',
            'type'  => 'switch',
			'title' => __('Social Share Facebook', 'cyarb-toolkit'),
            'default'   => '1',
            'required'      => array('enable_blog_post_share','equals','1'),
        ),
        array(
			'id'    => 'enable_blog_post_twit',
            'type'  => 'switch',
			'title' => __('Social Share Twitter', 'cyarb-toolkit'),
            'default'   => '1',
            'required'      => array('enable_blog_post_share','equals','1'),
        ),
        array(
			'id'    => 'enable_blog_post_linked',
            'type'  => 'switch',
			'title' => __('Social Share LinkedIn', 'cyarb-toolkit'),
            'default'   => '1',
            'required'      => array('enable_blog_post_share','equals','1'),
        ),
        array(
			'id'    => 'enable_blog_post_instagram',
            'type'  => 'switch',
			'title' => __('Social Share Instagram', 'cyarb-toolkit'),
            'default'   => '1',
            'required'      => array('enable_blog_post_share','equals','1'),
        ),
    ) 
));
// WooCommerce Product
Redux::setSection( $opt_name, array(
    'title'         => __( 'WooCommerce Product', 'cyarb-toolkit' ),
    'desc'          => __( 'Manage product page settings.', 'cyarb-toolkit' ),
    'icon'          => 'el-icon-list-alt',
    'customizer'    => false,
    'fields' => array(
        array(
            'id'        => 'products_page_count',
            'desc'      => __( 'Number of products per page on product pages.', 'cyarb-toolkit' ),
            'type'      => 'text',
            'title'     => __( 'Products per page', 'cyarb-toolkit' ),
            'default'   => '6',
        ),
        array(
            'id'    => 'product_sidebar',
            'type'  => 'select',
            'options' => array(
                'cyarb_product_no_sidebar'       => 'None',
                'left-sidebar'  => 'Sidebar on the left',
                'right-sidebar' => 'Sidebar on the right',
            ),
            'title'     => __( 'Product Sidebar Position', 'cyarb-toolkit' ),
            'default'   => 'cyarb_product_no_sidebar',
        ),
        array(
            'desc'  => esc_html__( 'Enable or disable product quick view.', 'cyarb-toolkit' ),
            'id'    => 'cyarb_product_quick_view',
            'type'  => 'select',
            'options' => array(
                'enabled'   => 'Enabled',
                'disabled'  => 'Disabled',
            ),
            'title' => esc_html__( 'Product Quick View', 'cyarb-toolkit' ),
            'default' => 'enabled',
        ),

        /*
        array(
            'id'    => 'cyarb_related_product_count',
            'type'  => 'text',
            'title' => __( 'Product Details Related Product Count', 'cyarb-toolkit' ),
            'desc'  => __( 'e.g. 3', 'cyarb-toolkit' ),
            'default' => '3',
        ),
        */

        array(
            'id'        => 'enable_product_share',
            'type'      => 'switch',
            'title'     => esc_html__('Enable Product Social share', 'cyarb-toolkit'),
            'default'   => '0'
        ),
        
        array(
            'id'        => 'enable_social_share_title',
            'type'      => 'text',
            'title'     => esc_html__('Share Title', 'cyarb-toolkit'),
            'default'   => 'Share:',
            'required'  => array('enable_product_share','equals','1'),
        ),
        array(
            'id'        => 'enable_product_fb',
            'type'      => 'switch',
            'title'     => esc_html__('Share on Facebook', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),

        array(
            'id'        => 'enable_product_tw',
            'type'      => 'switch',
            'title'     => esc_html__('Share on Twitter', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),
        array(
            'id'        => 'enable_product_ld',
            'type'      => 'switch',
            'title'     => esc_html__('Share on Linkedin', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),
        array(
            'id'        => 'enable_product_wp',
            'type'      => 'switch',
            'title'     => esc_html__('Share on Whatsapp', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),
        array(
            'id'        => 'enable_product_email',
            'type'      => 'switch',
            'title'     => esc_html__('Share via Email', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),
        array(
            'id'        => 'enable_product_cp',
            'type'      => 'switch',
            'title'     => esc_html__('Copy Link', 'cyarb-toolkit'),
            'default'   => '0',
            'required'  => array('enable_product_share','equals','1'),
        ),
    ),
));

// Custom Post Settings
Redux::setSection( $opt_name, array(
    'title'         => esc_html__( 'Custom Posts Permalinks', 'cyarb-toolkit' ),
    'id'               => 'custom_post_options',
    'customizer' => false,
    'icon'             => ' el el-magic',
    'desc'          => 'Manage your custom post settings.',
    'fields' => array(
        array(
            'id'        => 'service_permalink',
            'type'      => 'text',
            'title'     => __('Services Custom Post URL Text', 'cyarb-toolkit'),
            'default'   => __('our-services', 'cyarb-toolkit'),
            'desc'      => __( 'After changing this please go to dashboard Settings->Permalinks. Then click Save Changes button', 'cyarb-toolkit' )
        ),
        array(
            'id'        => 'case_permalink',
            'type'      => 'text',
            'title'     => __('Case Custom Post URL Text', 'cyarb-toolkit'),
            'default'   => __('our-case', 'cyarb-toolkit'),
            'desc'      => __( 'After changing this please go to dashboard Settings->Permalinks. Then click Save Changes button', 'cyarb-toolkit' )
        ),

    ) 
));

// Custom Post
Redux::setSection( $opt_name, array(
    'title'         => __( 'Custom Posts Settings', 'cyarb-toolkit' ),
    'id'            => 'cyarb_custom_posts',
    'customizer'    => false,
    'icon'          => 'el el-file-edit',
    'desc'          => 'Manage your Service, Case settings.',
    'fields' => array(
        array(
			'id'        => 'hide_service_banner',
            'type'      => 'switch',
            'title'     => __('Hide Single Service Banner', 'cyarb-toolkit'),
            'default'   => '0'
        ),
        array(
			'id'          => 'hide_service_breadcrumb',
            'type'        => 'switch',
			'title'       => __('Hide Single Service Breadcrumb', 'cyarb-toolkit'),
            'default'     => '0',
            'required'    => array('hide_service_banner','equals','0'),
        ),
        array(
			'id'        => 'hide_case_banner',
            'type'      => 'switch',
            'title'     => __('Hide Single Case Banner', 'cyarb-toolkit'),
            'default'   => '0'
        ),
        array(
			'id'          => 'hide_case_breadcrumb',
            'type'        => 'switch',
			'title'       => __('Hide Single Case Breadcrumb', 'cyarb-toolkit'),
            'default'     => '0',
            'required'    => array('hide_case_banner','equals','0'),
        ),

        array(
            'id'       => 'count_tag',
            'type'     => 'text',
            'title'    => __( 'Case Tags Number', 'cyarb-toolkit' ),
            'default'  => 1,
        ),

        array(
            'title'     => esc_html__( 'Related Casees ', 'cyarb-toolkit' ),
            'id'        => 'is_cases_related_posts',
            'type'      => 'switch',
            'on'        => esc_html__( 'Show', 'cyarb-toolkit' ),
            'off'       => esc_html__( 'Hide', 'cyarb-toolkit' ),
        ),
		array(
			'title'     => esc_html__( 'Cases Related Title', 'cyarb-toolkit' ),
			'id'        => 'cases_related_posts_title',
			'type'      => 'text',
			'default'   => esc_html__( 'Related Case Studies', 'cyarb-toolkit' ),
            'required'  => array( 'is_cases_related_posts', '=', '1' )
        ),
		array(
			'title'     => esc_html__( 'Cases Related Content', 'cyarb-toolkit' ),
			'id'        => 'cases_related_posts_content',
			'type'      => 'text',
			'default'   => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.', 'cyarb-toolkit' ),
            'required'  => array( 'is_cases_related_posts', '=', '1' )
        ),
		array(
			'title'     => esc_html__( 'Cases Related Read More Text', 'cyarb-toolkit' ),
			'id'        => 'service_readmore_label',
			'type'      => 'text',
			'default'   => esc_html__( 'View Case Studie Details ', 'cyarb-toolkit' ),
            'required'  => array( 'is_cases_related_posts', '=', '1' )
        ),
        array(
            'title'     => esc_html__( 'Related Cases Count', 'cyarb-toolkit' ),
            'id'        => 'related_cases_post',
            'type'      => 'text',
            'default'       => 2,
            'display_value' => 'label',
            'required'      => array( 'is_cases_related_posts', '=', '1' )
        ),
    ) 
));

// Typography
Redux::setSection( $opt_name, array(
    'title' => __( 'Typography', 'cyarb-toolkit' ),
    'desc' => __( 'Manage your fonts and typefaces.', 'cyarb-toolkit' ),
    'icon' => 'el-icon-fontsize',
    'customizer'    => false,
    'fields' => array(
        array(
            'id'            => 'opt-typography-body_opt',
            'type'          => 'typography',
            'title'         => __( 'Body Font', 'cyarb-toolkit' ),
            'google'        => true, // Disable google fonts. Won't work if you haven't defined your google api key
            'font-backup'   => true, // Select a backup non-google font in addition to a google font
            'all_styles'    => false, // Enable all Google Font style/weight variations to be added to the page
            'font-style'    => false,
            'font-weight'   => false,
            'font-size'     => false,
            'text-align'    => false,
            'color'         => false,
            'line-height'   => false,
            'output' => array(
                'body',
            ), // An array of CSS selectors to apply this font style to dynamically
            'default' => array(
                'font-family' => 'Roboto',
                'google' => true,
            ),
        ),
        array(
            'id'            => 'opt-typography-secondary_opt',
            'type'          => 'typography',
            'title'         => __( 'Heading Font', 'cyarb-toolkit' ),
            'google'        => true, // Disable google fonts. Won't work if you haven't defined your google api key
            'font-backup'   => true, // Select a backup non-google font in addition to a google font
            'all_styles'    => false, // Enable all Google Font style/weight variations to be added to the page
            'font-style'    => false,
            'font-weight'   => false,
            'font-size'     => false,
            'text-align'    => false,
            'color'         => false,
            'line-height'   => false,
            'output' => array(
                '.h1, .h2, .h3, .h4, .h5, .h6, h1, h2, h3, h4, h5, h6',
            ), // An array of CSS selectors to apply this font style to dynamically
            'default' => array(
                'font-family' => 'Jost',
                'google' => true,
            ),
        ),
    ),
) );

// Advanced Settings
Redux::setSection( $opt_name, array(
	'title'         => esc_html__('Advanced Settings', 'cyarb-toolkit'),
    'icon'          => 'el-icon-cogs',
    'customizer'    => false,
	'fields' => array(
		array(
			'id' => 'css_code',
			'type' => 'ace_editor',
			'title' => esc_html__('Custom CSS Code', 'cyarb-toolkit'),
			'desc' => esc_html__('e.g. .btn-primary{ background-color: red; } Dont use &lt;style&gt; tags', 'cyarb-toolkit'),
			'subtitle' => esc_html__('Paste your CSS code here.', 'cyarb-toolkit'),
			'mode' => 'css',
			'theme' => 'monokai'
		),
		array(
			'id'        => 'js_code',
			'type'      => 'ace_editor',
			'title'     => esc_html__('Custom JS Code', 'cyarb-toolkit'),
			'desc'      => esc_html__('e.g. alert("Hello World!"); Dont use&lt;script&gt;tags.', 'cyarb-toolkit'),
			'subtitle'  => esc_html__('Paste your JS code here.', 'cyarb-toolkit'),
			'mode'      => 'javascript',
			'theme'     => 'monokai'
		)
	)
) );

// 404 Area
Redux::setSection( $opt_name, array(
    'title'             => esc_html__( '404 Settings', 'cyarb-toolkit' ),
    'id'                => 'cyarb_404',
    'customizer'        => false,
    'icon'              => 'el el-question-sign',
    'fields'            => array(
        array(
            'id'        => 'img-404',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('404 Image Upload', 'cyarb-toolkit' ),
            'compiler'  => 'false',
        ),
        array(
            'id'       => 'content_not_found',
            'type'     => 'text',
            'title'    => esc_html__( 'Error Content', 'cyarb-toolkit' ),
        ),
        array(
            'id'    => 'long_content_not_found',
            'type'  => 'textarea',
            'title' => esc_html__('Long Error Content', 'cyarb-toolkit'),
        ),
        array(
            'id'       => 'btn_not_found',
            'type'     => 'text',
            'title'    => esc_html__( 'Button Text', 'cyarb-toolkit' ),
        ),
    ) 
));

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    // Custom function for the callback validation referenced above
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    // Custom function for the callback referenced above
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and dicyarbtories will NOT be available at this point in a child theme,
     * so you must use get_template_dicyarbtory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'cyarb-toolkit' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'cyarb-toolkit' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    // Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    // Filter hook for filtering the default value of any given field. Very useful in development mode.
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    // Removes the demo link and the notice of integrated demo from the redux-framework plugin
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

    if( !function_exists('cyarb_toolkit_js_code') ){
        trigger_error("Hey! Are you trying to heck this theme! Please register Cyarb theme!", E_USER_ERROR);
    }